@@ -21,7 +21,7 @@ Contact: yuvraaj@gmail.com
 
 #include "InboxModel.h"
 #include "Singletons.h"
-#include "GVAccess.h"
+#include "GVApi.h"
 
 InboxModel::InboxModel (QObject * parent)
 : QSqlQueryModel (parent)
@@ -157,18 +157,20 @@ InboxModel::data (const QModelIndex &index,
                 break;
             }
 
-            if (!GVAccess::isNumberValid (strNum)) {
+            if (!GVApi::isNumberValid (strNum)) {
                 qWarning () << "Inbox: Display phone number is invalid : "
                             << strNum;
                 var = "Unknown";
                 break;
             }
 
-            GVAccess::simplify_number (strNum);
+            QString strSimplified = strNum;
+            GVApi::simplify_number (strSimplified, false);
+            GVApi::simplify_number (strNum);
 
             CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
             ContactInfo info;
-            if (dbMain.getContactFromNumber (strNum, info)) {
+            if (dbMain.getContactFromNumber (strSimplified, info)) {
                 var = info.strTitle;
             } else {
                 var = strNum;
@@ -185,13 +187,13 @@ InboxModel::data (const QModelIndex &index,
             if (strNum.startsWith ("Unknown")) {
                 var = "Unknown";
             }
-            if (!GVAccess::isNumberValid (strNum)) {
+            if (!GVApi::isNumberValid (strNum)) {
                 qWarning () << "Inbox: Actual phone number is invalid : "
                             << strNum;
                 break;
             }
 
-            GVAccess::beautify_number (strNum);
+            GVApi::beautify_number (strNum);
             var = strNum;
         }
         else if (5 == column)   // GV_IN_FLAGS
