@@ -391,6 +391,9 @@ MainWindow::initQML ()
     bool bTempFalse = false;
     int iTempZero = 0;
 
+    double hMul, wMul, fontMul;
+    osd.getMultipliers (hMul, wMul, fontMul);
+
     // Prepare the globally accessible variants for QML.
     QDeclarativeContext *ctx = this->rootContext();
     ctx->setContextProperty ("g_bShowMsg", bTempFalse);
@@ -402,6 +405,9 @@ MainWindow::initQML ()
     ctx->setContextProperty ("g_CurrentPhoneName", "Not loaded");
     ctx->setContextProperty ("g_vmailPlayerState", iTempZero);
     ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
+    ctx->setContextProperty ("g_hMul", hMul);
+    ctx->setContextProperty ("g_wMul", wMul);
+    ctx->setContextProperty ("g_fontMul", fontMul);
 
     // Initialize the QML view
     this->setSource (QUrl(osd.getMainQML()));
@@ -581,212 +587,6 @@ MainWindow::connectSettingsSignals()
     return (rv);
 }//MainWindow::connectSettingsSignals
 
-/** Invoked to begin the login process.
- * We already have the username and password, so just start the login to the GV
- * website. The async completion routine is loginCompleted.
- */
-void
-MainWindow::doLogin ()
-{
-    OsDependent &osd = Singletons::getRef().getOSD ();
-    AsyncTaskToken *token = new AsyncTaskToken(this);
-    bool bOk = false;
-
-    do { // Begin cleanup block (not a loop)
-        if (!token) {
-            Q_WARN("Failed to allocate token");
-            break;
-        }
-
-        bOk = connect(token, SIGNAL(completed(AsyncTaskToken*)),
-                      this , SLOT(loginCompleted(AsyncTaskToken*)));
-
-        token->inParams["user"] = strUser;
-        token->inParams["pass"] = strPass;
-
-        Q_DEBUG("Login using user ") << strUser;
-        setStatus ("Logging in...", 0);
-
-        osd.setLongWork (this, true);
-
-        if (!gvApi.login (token)) {
-            Q_WARN("Login returned immediately with failure!");
-            osd.setLongWork (this, false);
-            break;
-        }
-
-        bOk = true;
-    } while (0); // End cleanup block (not a loop)
-
-    if (!bOk) {
-        if (token) {
-            token->deleteLater ();
-            token = NULL;
-        }
-
-        // Cleanup if any
-        strUser.clear ();
-        strPass.clear ();
-
-        logoutCompleted (NULL);
-    }
-}//MainWindow::doLogin
-
-void
-MainWindow::onUserTextChanged (const QString &strUsername)
-{
-    if (strUser != strUsername) {
-        strUser = strUsername;
-        this->setUsername (strUser);
-    }
-}//MainWindow::onUserTextChanged
-
-void
-MainWindow::onPassTextChanged (const QString &strPassword)
-{
-    if (strPass != strPassword) {
-        strPass = strPassword;
-
-        QList<QNetworkCookie> noCookies;
-        gvApi.setAllCookies(noCookies);
-        this->setPassword (strPass);
-    }
-}//MainWindow::onUserPassTextChanged
-
-/** SLOT: Invoked when user triggers the login/logout action
- * If it is a login action, the Login dialog box is shown.
- */
-void
-MainWindow::on_action_Login_triggered ()
-{
-    if (!bLoggedIn) {
-        QDeclarativeContext *ctx = this->rootContext();
-        ctx->setContextProperty ("g_bShowSettings", true);
-    } else {
-        doLogout ();
-    }
-}//MainWindow::on_action_Login_triggered
-
-void
-MainWindow::loginCompleted (AsyncTaskToken *token)
-{
-    if (!token || (token->status != ATTS_SUCCESS)) {
-        logoutCompleted (NULL);
-
-        OsDependent &osd = Singletons::getRef().getOSD ();
-        osd.setLongWork (this, false);
-
-        setStatus ("User login failed", 30*1000);
-
-        QString strErr;
-        if (token) {
-            strErr = token->errorString;
-        }
-        if (strErr.isEmpty ()) {
-            strErr = "User login failed";
-        }
-        this->showMsgBox (strErr);
-
-        Q_WARN("User login failed. Error string: ") << strErr;
-
-        QTimer::singleShot (500, this, SLOT(onRecreateCookieJar()));
-    } else {
-        CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
-        setStatus ("User logged in");
-        Q_DEBUG ("User logged in");
-
-        QString strOldUser, strOldPass;
-        dbMain.getUserPass (strOldUser, strOldPass);
-        if (strOldUser != strUser) {
-            // Cleanup cache
-            dbMain.blowAwayCache ();
-            dbMain.ensureCache ();
-        }
-
-        // Prepare then contacts
-        initContacts ();
-        // Prepare the inbox widget for usage
-        initInbox ();
-
-        // Allow access to buttons and widgets
-        actLogin.setText ("Logout");
-        bLoggedIn = true;
-
-        // Save the user name and password that was used to login
-        dbMain.putUserPass (strUser, strPass);
-
-        this->setUsername (strUser);
-        this->setPassword (strPass);
-        QDeclarativeContext *ctx = this->rootContext();
-        ctx->setContextProperty ("g_bIsLoggedIn", bLoggedIn);
-        bool bTemp = false;
-        ctx->setContextProperty ("g_bShowSettings", bTemp);
-
-        // Fill up the combobox on the main page
-        refreshRegisteredNumbers ();
-
-        // Fill up the mq settings
-        initMq ();
-
-        // Fill up the pin settings
-        refreshPinSettings ();
-    }
-
-    if (token) {
-        delete token;
-    }
-}//MainWindow::loginCompleted
-
-void
-MainWindow::doLogout ()
-{
-    AsyncTaskToken *token = new AsyncTaskToken(this);
-    connect (token, SIGNAL(completed(AsyncTaskToken*)),
-             this, SLOT(logoutCompleted(AsyncTaskToken*)));
-
-    if (!gvApi.logout (token)) {
-        token->deleteLater ();
-        return;
-    }
-
-    OsDependent &osd = Singletons::getRef().getOSD ();
-    osd.setLongWork (this, true);
-
-    oContacts.deinitModel ();
-    oInbox.deinitModel ();
-
-#if MOSQUITTO_CAPABLE
-    mqThread.setQuit ();
-#endif
-}//MainWindow::doLogout
-
-void
-MainWindow::logoutCompleted (AsyncTaskToken *token)
-{
-    // This clears out the table and the view as well
-    deinitContacts ();
-    deinitInbox ();
-
-    arrNumbers.clear ();
-
-    actLogin.setText ("Login...");
-
-    bLoggedIn = false;
-
-    QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_bIsLoggedIn", bLoggedIn);
-
-    setStatus ("Logout complete");
-    Q_DEBUG ("Logout complete");
-
-    OsDependent &osd = Singletons::getRef().getOSD ();
-    osd.setLongWork (this, false);
-
-    if (token) {
-        token->deleteLater ();
-    }
-}//MainWindow::logoutCompleted
-
 void
 MainWindow::systray_activated (QSystemTrayIcon::ActivationReason reason)
 {
@@ -1248,38 +1048,6 @@ MainWindow::onCallInitiatorsChange (bool bSave)
     onRegPhoneSelectionChange (indRegPhone);
 }//MainWindow::onCallInitiatorsChange
 
-void
-MainWindow::setUsername(const QString &strU)
-{
-    do // Begin cleanup block (not a loop)
-    {
-        QObject *pSettingsPage = getQMLObject ("SettingsPage");
-        if (NULL == pSettingsPage) {
-            Q_WARN("Could not get to SettingsPage for setUsername");
-            break;
-        }
-
-        QMetaObject::invokeMethod (pSettingsPage, "setUsername",
-                                   Q_ARG (QVariant, QVariant(strU)));
-    } while (0); // End cleanup block (not a loop)
-}//MainWindow::setUsername
-
-void
-MainWindow::setPassword(const QString &strP)
-{
-    do // Begin cleanup block (not a loop)
-    {
-        QObject *pSettingsPage = getQMLObject ("SettingsPage");
-        if (NULL == pSettingsPage) {
-            Q_WARN("Could not get to SettingsPage for setPassword");
-            break;
-        }
-
-        QMetaObject::invokeMethod (pSettingsPage, "setPassword",
-                                   Q_ARG (QVariant, QVariant(strP)));
-    } while (0); // End cleanup block (not a loop)
-}//MainWindow::setPassword
-
 void
 MainWindow::fallbackDialout (DialContext *ctx)
 {
